@@ -93,21 +93,20 @@ class ZeebeWorker:
 
                 # Handling errors with a backoff
                 if e.code() == grpc.StatusCode.UNAVAILABLE:
-                    logging.error('Cannot connect to Zeebe, retrying with backoff\n' + repr(e))
+                    logging.error('Cannot connect to Zeebe, '
+                                 f'retrying in {backoff_interval} ms')
                     time.sleep(backoff_interval / 1000)
                 elif e.code() == grpc.StatusCode.RESOURCE_EXHAUSTED:
-                    logging.error(
-                        'Zeebe cannot handle this amount of requests, retrying with a backoff\n'
-                        + repr(e))
+                    logging.warn('Zeebe cannot handle this amount of requests, '
+                                f'retrying in {backoff_interval} ms')
                     time.sleep(backoff_interval / 1000)
                 elif e.code() == grpc.StatusCode.INTERNAL:
-                    logging.error('Zeebe had an internal error between the gateway and the broker \
-                                   Retrying with a backoff\n' + repr(e))
+                    logging.warn('Zeebe had an internal error between the gateway and the broker '
+                                f'retrying in {backoff_interval} ms')
                     time.sleep(backoff_interval / 1000)
                 # Silently handle all other errors and reconnect immediately
                 elif e.code() == grpc.StatusCode.DEADLINE_EXCEEDED:
-                    logging.debug(f'No jobs for {task_type} found\n' + repr(e))
+                    logging.debug(f'No jobs for {task_type} found')
                 elif e.code() == grpc.StatusCode.CANCELLED:
-                    logging.debug(f'Request for {task_type} cancelled\n' + repr(e))
-                else:
-                    logging.debug(repr(e))
+                    logging.info(f'Request for {task_type} cancelled')
+                logging.debug(repr(e))
